@@ -1,3 +1,6 @@
+/************************************************************
+Copyright (C) 2005 Masahiko SAWAI All Rights Reserved.
+************************************************************/
 #include "sdl4gcj/cdrom/CD.h"
 #include "sdl4gcj/cdrom/CDTrack.h"
 #include "sdl4gcj/SDLException.h"
@@ -12,6 +15,7 @@ using namespace java::lang;
 
 // function
 static
+inline
 ::sdl4gcj::SDLException*
 createNotOpenedException(CD* cd)
 {
@@ -25,6 +29,20 @@ createNotOpenedException(CD* cd)
 	return new sdl4gcj::SDLException(buffer->toString());
 }
 
+static
+inline
+::sdl4gcj::SDLException*
+createOpenFailedException(CD* cd)
+{
+	StringBuffer* buffer = new StringBuffer();
+	buffer->append(JvNewStringLatin1("CD drive(index = "));
+	buffer->append(cd->getIndex());
+	buffer->append(JvNewStringLatin1(") open failed : "));
+	buffer->append(JvNewStringLatin1(SDL_GetError()));
+	
+	return new sdl4gcj::SDLException(buffer->toString());
+}
+
 // class methods
 jint 
 CD::getNumDrives ()
@@ -67,6 +85,7 @@ CD::open ()
 	{
 		SDL_CD* nativeCD;
 		nativeCD = SDL_CDOpen(this->getIndex());
+		if (nativeCD == NULL) throw createOpenFailedException(this);
 		this->implementation = (::gnu::gcj::RawData*)nativeCD;
 	}
 }
