@@ -1,3 +1,6 @@
+/************************************************************
+Copyright (C) 2005 Masahiko SAWAI All Rights Reserved. 
+************************************************************/
 package sdl4gcj.mixer;
 
 import sdl4gcj.SDLException;
@@ -10,28 +13,16 @@ public class Music implements MixerConstants
 	protected gnu.gcj.RawData implementation = null;
 
 	// class methods
-	public static Music loadMUS(String filePath)
-	{
-		return new Music(filePath);
-	}
+
+	public static native Music loadMUS(String filePath);
 
 	public static Music loadMUS(File file)
 	{
-		return new Music(file.getAbsolutePath());
+		return loadMUS(file.getAbsolutePath());
 	}
 
 	// constructors
-	public Music(String filePath)
-	{
-		this.loadMusicFromFile(filePath);
-	}
-
-	public Music(File file)
-	{
-		this.loadMusicFromFile(file.getAbsolutePath());
-	}
-
-	private Music()
+	protected Music()
 	{
 	}
 
@@ -45,7 +36,5 @@ public class Music implements MixerConstants
 		this.freeMusic();
 		super.finalize();
 	}
-
-	private native void loadMusicFromFile(String filePath);
 }
 
