@@ -5,6 +5,7 @@ Copyright (C) 2005 Masahiko SAWAI All Rights Reserved.
 
 #include "sdl4gcj/ttf/FontConstants.h"
 #include "sdl4gcj/Version.h"
+#include "sdl4gcj/SDLException.h"
 
 #include <gcj/cni.h>
 #include <gcj/javaprims.h>
@@ -17,6 +18,7 @@ Copyright (C) 2005 Masahiko SAWAI All Rights Reserved.
 
 using namespace sdl4gcj::ttf;
 using sdl4gcj::Version;
+using sdl4gcj::SDLException;
 
 // function
 
@@ -53,12 +55,14 @@ TTFSystem::linkedVersion()
 	return linkedVersion;
 }
 
-jint
+void
 TTFSystem::init()
 {
 	JvInitClass(&TTFSystem::class$);
-
-	return TTF_Init();
+	if (TTF_Init() != 0)
+		throw new SDLException();
+	
+	return ;
 }
 
 jboolean
