@@ -1,3 +1,6 @@
+/************************************************************
+Copyright (C) 2005 Masahiko SAWAI All Rights Reserved. 
+************************************************************/
 #include "sdl4gcj/video/Surface.h"
 
 #include "sdl4gcj/video/PixelFormat.h"
@@ -17,6 +20,14 @@
 using namespace sdl4gcj::video;
 
 // function
+static
+inline
+sdl4gcj::SDLException*
+createLoadBMPFailedException()
+{
+	return new sdl4gcj::SDLException(JvNewStringLatin1(SDL_GetError()));
+}
+
 static
 inline
 sdl4gcj::SDLException*
@@ -59,7 +70,7 @@ Surface *
 Surface::loadBMP(::java::lang::String* filePath)
 {
 	JvInitClass(&Surface::class$);
-	Surface* result = NULL;
+	Surface* image = NULL;
 
 	jbyteArray byteArray = filePath->getBytes();
 	int length = JvGetArrayLength(byteArray);
@@ -69,31 +80,29 @@ Surface::loadBMP(::java::lang::String* filePath)
 	memcpy(buffer, bytes, length);
 	buffer[length] = '\0';
 
-	SDL_Surface* image = SDL_LoadBMP(buffer);
-	if (image != NULL)
-	{
-		result = new Surface();
-		result->implementation = (::gnu::gcj::RawData*)image;
-	}
+	SDL_Surface* nativeImage = SDL_LoadBMP(buffer);
+	if (nativeImage == NULL) throw createLoadBMPFailedException();
 
-	return result;
+	image = new Surface();
+	image->implementation = (::gnu::gcj::RawData*)nativeImage;
+
+	return image;
 }
 
 Surface *
 Surface::loadBMP(JArray<jbyte>* byteArray, jint offset, jint length)
 {
 	JvInitClass(&Surface::class$);
-	Surface* result = NULL;
+	Surface* image = NULL;
 	jbyte* bytes = elements(byteArray) + offset;
 
-	SDL_Surface* image = SDL_LoadBMP_RW(SDL_RWFromMem(bytes, length), 1);
-	if (image != NULL)
-	{
-		result = new Surface();
-		result->implementation = (::gnu::gcj::RawData*)image;
-	}
+	SDL_Surface* nativeImage = SDL_LoadBMP_RW(SDL_RWFromMem(bytes, length), 1);
+	if (nativeImage == NULL) throw createLoadBMPFailedException();
 
-	return result;
+	image = new Surface();
+	image->implementation = (::gnu::gcj::RawData*)nativeImage;
+
+	return image;
 }
 
 
