@@ -14,7 +14,7 @@ public class ImageTest implements SDLConstants
 
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDL_INIT_VIDEO) != 0) System.exit(0);
+		SDLSystem.init(SDL_INIT_VIDEO);
 
 		System.out.println(" Compiled SDL_image Version : " + IMGSystem.compiledVersion());
 		System.out.println("   Linked SDL_image Version : " + IMGSystem.linkedVersion());
