@@ -387,7 +387,7 @@ public class PlayMusic implements  SDLConstants, MixerConstants
 
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDL_INIT_VIDEO) != 0) System.exit(0);
+		SDLSystem.init(SDL_INIT_VIDEO);
 
 		try
 		{
@@ -400,7 +400,7 @@ public class PlayMusic implements  SDLConstants, MixerConstants
 
 			String musicFile = DEFAULT_MUSIC_FILE;
 			if (args.length > 0) musicFile = args[0];
-			Music music = new Music(musicFile);
+			Music music = Music.loadMUS(musicFile);
 
 			MusicPlayer player = new MusicPlayer(screen, mixer, music);
 			player.mainLoop();
