@@ -10,11 +10,7 @@ final public class ResourceIconTest
 {
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDLSystem.SDL_INIT_VIDEO) != 0)
-		{
-			System.out.println("Init() fail");
-			System.exit(0);
-		}
+		SDLSystem.init(SDLSystem.SDL_INIT_VIDEO);
 
 		try
 		{
