@@ -10,12 +10,7 @@ public class SaveBMPTest implements SDLConstants
 
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDLSystem.SDL_INIT_VIDEO) != 0)
-		{
-			System.out.println("Init() fail");
-			System.exit(0);
-		}
-
+		SDLSystem.init(SDLSystem.SDL_INIT_VIDEO);
 		try
 		{
 			Screen screen = Screen.setVideoMode(640, 480, 32, SDL_SWSURFACE|SDL_ANYFORMAT);
