@@ -3,18 +3,14 @@ import sdl4gcj.video.*;
 import sdl4gcj.event.*;
 import sdl4gcj.input.*;
 
-
 public class Test implements SDLConstants
 {
 	static final String SAVE_FILE = "saved.bmp";
 
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDL_INIT_VIDEO) != 0)
-		{
-			System.out.println("Init() fail");
-			System.exit(0);
-		}
+		SDLSystem.init(SDL_INIT_VIDEO);
+
 		System.out.println(" Compiled SDL Version : " + SDLSystem.compiledVersion());
 		System.out.println("   Linked SDL Version : " + SDLSystem.linkedVersion());
 
